ButtonBuilder

Struct ButtonBuilder 

pub struct ButtonBuilder { /* private fields */ }
Create a Button with a builder.

Implementations

Source

impl ButtonBuilder

pub fn build(self) -> Button

Consume this builder and return the configured Button

pub fn custom_emoji( self, name: Option<String>, id: Id<EmojiMarker>, animated: bool, ) -> Self

Set a custom emoji for this button.

This is unavailable for buttons with a SKU ID.

pub const fn disable(self) -> Self

Make this button disabled.

pub fn unicode_emoji(self, emoji: String) -> Self

Set a unicode emoji for this button.

This is unavailable for buttons with a SKU ID.

pub const fn with_custom_id( custom_id: String, label: String, style: ButtonStyle, ) -> Self

Create a new builder for a button with a given custom ID.

pub const fn with_sku_id(sku_id: Id<SkuMarker>) -> Self

Create a new builder for a button with ButtonStyle::Premium.

pub const fn with_url(url: String, label: String) -> Self

Create a new builder for a button with ButtonStyle::Link.