SelectMenuBuilder

Struct SelectMenuBuilder 

pub struct SelectMenuBuilder { /* private fields */ }
Create a SelectMenu with a builder.

Implementations

Source

impl SelectMenuBuilder

pub fn build(self) -> SelectMenu

Consume this builder and return the configured SelectMenuOption

pub fn default_values(self, default_values: Vec<SelectDefaultValue>) -> Self

Set the default values for this select menu.

This is not available for SelectMenuType::Text.

pub const fn disable(self) -> Self

Make this select menu disabled.

pub const fn max_values(self, max_values: u8) -> Self

Set the maximum number of options that can be chosen for this select menu.

pub const fn min_values(self, min_values: u8) -> Self

Set the minimum number of options that can be chosen for this select menu.

pub fn placeholder(self, placeholder: String) -> Self

Set the text to be shown when no options are selected.

pub const fn with_channel_types( custom_id: String, channel_types: Option<Vec<ChannelType>>, ) -> Self

Create a new builder for a select menu of SelectMenuType::Channel.

pub const fn with_kind(custom_id: String, kind: SelectMenuType) -> Self

Create a new builder for a select menu of a given SelectMenuType.

Prefer Self::with_options for SelectMenuType::Text and Self::with_channel_types for SelectMenuType::Channel.

pub const fn with_options( custom_id: String, options: Vec<SelectMenuOption>, ) -> Self

Create a new builder for a select menu of SelectMenuType::Text.