pub struct TextInputBuilder { /* private fields */ }Expand description
Create TextInput with a builder.
Implementations
Sourceimpl TextInputBuilder
impl TextInputBuilder
Sourcepub const fn max_length(self, max_length: u16) -> Self
pub const fn max_length(self, max_length: u16) -> Self
Set the maximum number of characters allowed to be entered into this text input.
Sourcepub const fn min_length(self, min_length: u16) -> Self
pub const fn min_length(self, min_length: u16) -> Self
Set the minimum number of characters allowed to be entered into this text input.
Sourcepub fn placeholder(self, placeholder: String) -> Self
pub fn placeholder(self, placeholder: String) -> Self
Set the placeholder of this text input.