pub struct ButtonBuilder { /* private fields */ }Expand description
Create a Button with a builder.
Implementations
Sourceimpl ButtonBuilder
impl ButtonBuilder
Sourcepub fn custom_emoji(
self,
name: Option<String>,
id: Id<EmojiMarker>,
animated: bool,
) -> Self
pub fn custom_emoji( self, name: Option<String>, id: Id<EmojiMarker>, animated: bool, ) -> Self
Set a custom emoji for this button.
This is unavailable for buttons with a SKU ID.
Sourcepub fn unicode_emoji(self, emoji: String) -> Self
pub fn unicode_emoji(self, emoji: String) -> Self
Set a unicode emoji for this button.
This is unavailable for buttons with a SKU ID.
Sourcepub const fn with_custom_id(
custom_id: String,
label: String,
style: ButtonStyle,
) -> Self
pub const fn with_custom_id( custom_id: String, label: String, style: ButtonStyle, ) -> Self
Create a new builder for a button with a given custom ID.
Sourcepub const fn with_sku_id(sku_id: Id<SkuMarker>) -> Self
pub const fn with_sku_id(sku_id: Id<SkuMarker>) -> Self
Create a new builder for a button with ButtonStyle::Premium.
Sourcepub const fn with_url(url: String, label: String) -> Self
pub const fn with_url(url: String, label: String) -> Self
Create a new builder for a button with ButtonStyle::Link.